# Proxy6 API wrapper
[![Build status](https://api.travis-ci.com/michaeldel/proxy6.svg?branch=master)](https://travis-ci.com/michaeldel/proxy6)
[![PyPI - Status](https://img.shields.io/pypi/v/proxysix)](https://pypi.org/project/proxysix/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/proxysix)](https://pypi.org/project/proxysix/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Install
Install the `proxysix` package with `pip`:
```
pip install proxysix
```
